def add_numbers(num1,num2):
    return num1+num2

def sub_numbers(num1,num2):
    return num1-num2

def multiply_numbers(num1,num2):
    return num1*num2

def divide_numbers(num1,num2):
    return num1/num2


